Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(862)

Unified Diff: chrome/browser/chromeos/policy/user_cloud_policy_manager_factory_chromeos.h

Issue 15517005: Remove references to Profile from browser_context_keyed_service. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/policy/user_cloud_policy_manager_factory_chromeos.h
diff --git a/chrome/browser/chromeos/policy/user_cloud_policy_manager_factory_chromeos.h b/chrome/browser/chromeos/policy/user_cloud_policy_manager_factory_chromeos.h
index c44a9fca1d5fbb65803e5d8baa820a22a7ee3497..57718974199e52a94758b9c84aac9e9d1c46fcf3 100644
--- a/chrome/browser/chromeos/policy/user_cloud_policy_manager_factory_chromeos.h
+++ b/chrome/browser/chromeos/policy/user_cloud_policy_manager_factory_chromeos.h
@@ -21,20 +21,20 @@ namespace policy {
class UserCloudPolicyManagerChromeOS;
// ProfileKeyedBaseFactory implementation for UserCloudPolicyManagerChromeOS
// instances that initialize per-profile cloud policy settings on ChromeOS.
//
// UserCloudPolicyManagerChromeOS is handled different than other
-// ProfileKeyedServices because it is a dependency of PrefService. Therefore,
+// BrowserContextKeyedServices because it is a dependency of PrefService. Therefore,
// lifetime of instances is managed by Profile, Profile startup code invokes
// CreateForProfile() explicitly, takes ownership, and the instance is only
// deleted after PrefService destruction.
//
// TODO(mnissler): Remove the special lifetime management in favor of
// PrefService directly depending on UserCloudPolicyManagerChromeOS once the
-// former has been converted to a ProfileKeyedService.
+// former has been converted to a BrowserContextKeyedService.
// See also http://crbug.com/131843 and http://crbug.com/131844.
-class UserCloudPolicyManagerFactoryChromeOS : public ProfileKeyedBaseFactory {
+class UserCloudPolicyManagerFactoryChromeOS : public BrowserContextKeyedBaseFactory {
public:
// Returns an instance of the UserCloudPolicyManagerFactoryChromeOS singleton.
static UserCloudPolicyManagerFactoryChromeOS* GetInstance();
@@ -65,9 +65,11 @@ class UserCloudPolicyManagerFactoryChromeOS : public ProfileKeyedBaseFactory {
Profile* profile,
bool force_immediate_load);
- // ProfileKeyedBaseFactory:
- virtual void ProfileShutdown(content::BrowserContext* context) OVERRIDE;
- virtual void ProfileDestroyed(content::BrowserContext* context) OVERRIDE;
+ // BrowserContextKeyedBaseFactory:
+ virtual void BrowserContextShutdown(
+ content::BrowserContext* context) OVERRIDE;
+ virtual void BrowserContextDestroyed(
+ content::BrowserContext* context) OVERRIDE;
virtual void SetEmptyTestingFactory(
content::BrowserContext* context) OVERRIDE;
virtual void CreateServiceNow(content::BrowserContext* context) OVERRIDE;
@@ -21,20 +21,20 @@ namespace policy {
class UserCloudPolicyManagerChromeOS;
-// ProfileKeyedBaseFactory implementation for UserCloudPolicyManagerChromeOS
+// BrowserContextKeyedBaseFactory implementation for UserCloudPolicyManagerChromeOS
// instances that initialize per-profile cloud policy settings on ChromeOS.
//

Powered by Google App Engine
This is Rietveld 408576698